# je_editor

---

[![Downloads](https://static.pepy.tech/badge/je-editor)](https://pepy.tech/project/je-editor)

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/825a90622a224207be4abe869775b50a)](https://www.codacy.com/gh/JE-Chen/je_editor/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=JE-Chen/je_editor&amp;utm_campaign=Badge_Grade)

[![JE_Editor Stable Python3.9](https://github.com/Intergration-Automation-Testing/je_editor/actions/workflows/stable_python3_9.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/je_editor/actions/workflows/stable_python3_9.yml)

[![JE_Editor Stable Python3.10](https://github.com/Intergration-Automation-Testing/je_editor/actions/workflows/stable_python3_10.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/je_editor/actions/workflows/stable_python3_10.yml)

[![JE_Editor Stable Python3.11](https://github.com/Intergration-Automation-Testing/je_editor/actions/workflows/stable_python3_11.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/je_editor/actions/workflows/stable_python3_11.yml)

### Document

[![Documentation Status](https://readthedocs.org/projects/je-editor/badge/?version=latest)](https://je-editor.readthedocs.io/en/latest/?badge=latest)

[JEditor Doc Click Here!](https://je-editor.readthedocs.io/en/latest/)

---


![Editor Picture](image/JEditor.png)
> * Project Kanban https://github.com/orgs/Integration-Automation/projects/2/views/1
> * Modern Editor.
> * Old JEditor remake.
> * AutoSave, Encoding Feature.
> * Multi program and shell runner.
> * Including yapf python format checker.
> * Including reformat JSON.
> * Virtual Environment support. 
> * Dark & Light mode ui support.
> * File tree support.
> * Line code.
> * Current line highlight.
> * Python code highlight.
> * Performance efficiency than old JEditor 1000%.
> * OS Independent.

* Include FrontEngine & FrontEngine GPT

---

## Requires

```
python 3.9 or later
```

## install

```commandline
pip install je_editor
```

* Test on
    * windows 10 ~ 11
    * osx 10.5 ~ 11 big sur
    * ubuntu 20.0.4
    * raspberry pi 3B+

| All test in test dir

### Architecture Diagram
![Architecture Diagram](architecture_diagram/JEditor_Architecture.drawio.png)
